/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2017 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.genomeview.gui;

import java.lang.management.ManagementFactory;
import java.lang.reflect.InvocationTargetException;
import java.net.Authenticator;
import java.util.Arrays;
import java.util.Date;
import java.util.concurrent.ExecutionException;

import javax.swing.SwingUtilities;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import be.abeel.concurrency.DaemonThread;
import net.sf.genomeview.core.Configuration;
import net.sf.genomeview.data.Model;

/**
 * 
 * @author Thomas Abeel
 * 
 */
public class GenomeView {
	private static Logger logger = LoggerFactory.getLogger(GenomeView.class.getCanonicalName());

	private static WindowManager mw;

	/*
	 * Rewrite args if started from file association
	 */
	private static void jnlprewrite(String[] args) {
		if (args.length > 0 && args[0].equals("-open"))
			args[0] = "--file";

	}

	private static Splash splash = null;

	public static Model getModel() {
		if (mw == null)
			return null;
		return mw.getModel();
	}

	public static void main(final String[] args) {
		LogConfigurator.config();
		logger.info("Starting GenomeView " + Configuration.version());
		logger.info("Using language: "+MessageManager.getLocale());
		try {
			SwingUtilities.invokeAndWait(new Runnable() {

				@Override
				public void run() {

					splash = new Splash();
				}
			});
		} catch (InterruptedException e1) {
			// Ignore, it's not like we really care
		} catch (InvocationTargetException e1) {
			// Ignore, it's not like we really care
		}

		/* Rewrite JNLP arguments */
		jnlprewrite(args);
		

		new DaemonThread(new Runnable() {

			@Override
			public void run() {
				
				/*
				 * The configuration class needs to be called at least once before we
				 * can start the logger
				 */
				
				
				
				logger.info("Configuration summary: \n\tGenomeView version: " + Configuration.version() + "\n\t" + "Current date and time: " + new Date() + "\n\t"
						+ "Command line instructions: " + Arrays.toString(args) + "\n\t" + "Number of processors: "
						+ Integer.toString(Runtime.getRuntime().availableProcessors()) + "\n\t" + "Free memory :"
						+ Long.toString(Runtime.getRuntime().freeMemory()) + "\n\t" + "Max memory: " + Long.toString(Runtime.getRuntime().maxMemory()) + "\n\t"
						+ "Total JVM: " + Long.toString(Runtime.getRuntime().totalMemory()) + "\n\t" + "OS: "
						+ ManagementFactory.getOperatingSystemMXBean().getName() + " " + ManagementFactory.getOperatingSystemMXBean().getVersion() + "\n\t"
						+ "Architecture: " + ManagementFactory.getOperatingSystemMXBean().getArch() + "\n\t" + "JVM version: "
						+ System.getProperty("java.version")

				);

				

				CommandLineOptions.init(args);
				/* Single instance manager */
				boolean singleInstance = Configuration.getBoolean("general:singleInstance");
				if (singleInstance) {
					if (!ApplicationInstanceManager.registerInstance(args)) {
						// instance already running.
						System.out.println("Another instance of this application is already running.  Exiting.");
						splash.dispose();
						StaticUtils.forceExit();
						return;
					}

				}

				Authenticator.setDefault(new MyAuthenticator());

				try {
					mw = new WindowManager(args, splash);
					ApplicationInstanceManager.setCallback(mw);
				} catch (InterruptedException e) {
					logger.error( "main window initialization", e);
				} catch (ExecutionException e) {
					logger.error( "main window initialization", e);
				}
				splash.dispose();
			}
		}).start();
	}
}
