/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2017 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.jannot.parser;

import java.util.SortedSet;
import java.util.TreeSet;

import net.sf.jannot.Location;
import net.sf.jannot.Strand;

public class ParserTools {
	public static Strand getStrand(String location) {
		if (location.toString().contains("complement"))
			return Strand.REVERSE;
		else
			return Strand.FORWARD;
	}

	public static SortedSet<Location> parseLocation(String location) {
		SortedSet<Location> out = new TreeSet<Location>();
		String t = location.toString().replaceAll("complement\\((.*?)\\)", "$1");
		String y = t.replaceAll("order\\((.*?)\\)", "$1");
		String x = y.replaceAll("join\\((.*?)\\)", "$1");
		
		String[] arr = x.split(",");
		for (String s : arr) {
			String[] pos = s.split("\\.\\.");
			int start, end;
			boolean fuzzyStart = false, fuzzyEnd = false;
			if (pos[0].startsWith("<")) {

				start = Integer.parseInt(pos[0].substring(1));
				fuzzyStart = true;
			} else
				start = Integer.parseInt(pos[0]);

			if (pos.length == 1) {
				end=start;
					
			} else if (pos[1].startsWith(">")) {

				end = Integer.parseInt(pos[1].substring(1));
				fuzzyEnd = true;
			} else
				end = Integer.parseInt(pos[1]);
			out.add(new Location(start, end, fuzzyStart, fuzzyEnd));

		}

		return out;
	}

}
