/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2017 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.jannot.pileup;

import cern.colt.Arrays;


/**
 * @author Thomas Abeel
 * 
 */
public class MultiPile extends DoublePile {

	private float[] val;

	private double sum=0;
	
	public String toString(){
		return super.start()+"="+Arrays.toString(val);
		
	}
	
	public MultiPile(int pos, float[] arr) {
		super(pos, arr.length>0?arr[0]:Float.NaN, arr.length>1?arr[1]:Float.NaN);
		this.val=arr;
		for(float f:val)
			sum+=f;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sf.jannot.pileup.DoublePile#getValueCount()
	 */
	@Override
	public int getValueCount() {
		return val.length;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sf.jannot.pileup.DoublePile#getValue(int)
	 */
	@Override
	public float getValue(int i) {
		return val[i];
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sf.jannot.pileup.DoublePile#getTotal()
	 */
	@Override
	public float getTotal() {
		return (float)sum;
	}

}
