/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2017 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.jannot.refseq;

import net.sf.jannot.Data;
/**
 * 
 * @author Thomas Abeel
 *
 */
public abstract class Sequence implements Data<Character> {


	public String label(){
		return "Sequence";
	}
	
	public boolean canSave(){
		return false;
	}
	
	public abstract int size();

	/**
	 * Gets a subsequence from this sequence. The selected sequence is
	 * [start,end[. The coordinates are one based.
	 * 
	 * @param start
	 *            the start coordinate, this one will be included in the
	 *            sequence. This is a one-based coordinate.
	 * @param end
	 *            the end coordinate, this one will not be included in the
	 *            sequence. This is a one-based coordinate.
	 * @return the selected subsequence.
	 */
	@Override
	public abstract Iterable<Character> get(int start, int end);

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sf.jannot.Data#get()
	 */
	@Override
	public abstract Iterable<Character> get();
	
	/**
	 * Coordinates are 1-based, cover [start,end[
	 * @param start
	 * @param end
	 * @return
	 */
	public Sequence subsequence(int start,int end){
		return new SubSequence(this, start,end);
	}
	/**
	 * Use this method sparingly as it can be a fairly expensive operation
	 * @return
	 */
	public String stringRepresentation(){
		StringBuffer out=new StringBuffer(size());
		for(Character c:get()){
			out.append(c);
		}
		return out.toString();
	}

}
