/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2017 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.jannot.shortread;

import net.sf.jannot.Data;
import net.sf.samtools.SAMRecord;

/**
 * 
 * @author Thomas Abeel
 * 
 */
public abstract class ReadGroup implements Data<SAMRecord> {

	/**
	 * Returns the maximum length of a read. In case this information is not
	 * available, it is sufficient to return the maximum length so far
	 * encountered in the get() or get(start,end) queries.
	 */
	public abstract int readLength();

	/**
	 * 
	 * Get the second read in a mate-pair.
	 * 
	 * @param one
	 *            the read for which to find the mate
	 * @return the mate
	 */
	public abstract SAMRecord getSecondRead(SAMRecord one);

	/**
	 * Returns the maximum length of a pair of reads.
	 * 
	 * The length of a pair is defined as the distance between the start of the
	 * first read and the end of the second.
	 * 
	 * In case this information is not available, it is sufficient to return the
	 * maximum pair length so far encountered in the get() or get(start,end)
	 * queries.
	 */
	public abstract int getPairLength();

	public boolean canSave() {
		return false;
	}

	/**
	 * @param second
	 * @return
	 */
	public abstract SAMRecord getFirstRead(SAMRecord second) ;

}
